@@ -51,7 +51,7 @@ namespace Oxygen
         void setMode( int );
 
         //! event filter
-        virtual bool eventFilter( QObject*, QEvent* );
+        bool eventFilter( QObject*, QEvent* ) ;
 
         //! true if mnemonics are enabled
         const bool& enabled( void ) const
